@@ -1,5 +1,5 @@
 #
-# $Date: 2005/03/15 21:15:49 $
+# $Date: 2005/10/13 17:02:33 $
 #
 # Data / Content layer functions
 #
@@ -308,7 +308,7 @@ sub print_ifind {
           . "<a href=\"$::PROGNAME?mod=$::MOD_FRAME&submod=$::MOD_META&$Args::baseargs&"
           . "meta=$meta\" target=\"_top\">$meta</a><br>\n";
 
-        print "<b>Pointed to by file:</b><br>\n";
+        print "<b>Pointed to by file:</b>\n";
         Exec::exec_pipe(*OUT,
             "'$::TSKDIR/ffind' -f $ftype -a -o $offset -i $imgtype $img $meta");
         while ($_ = Exec::read_pipe_line(*OUT)) {
@@ -362,7 +362,7 @@ sub content_menu {
         Print::print_err("Invalid length: 0");
     }
 
-    print "<center><font size=3>";
+    print "<center>";
     my $url =
         "$::PROGNAME?mod=$::MOD_DATA&view=$Data::CONT_MENU_FR&"
       . "$Args::baseargs&sort=$sort&len=$len"
@@ -485,8 +485,6 @@ sub content_menu {
     }
     if ($Fs::is_fs{$ftype} == 1) {
 
-        # if (($ftype ne "swap") && ($ftype ne "raw") && ($ftype ne "dls")) {
-
         Exec::exec_pipe(*OUT,
             "'$::TSKDIR/dstat' -f $ftype  -o $offset -i $imgtype $img $block");
 
@@ -495,7 +493,7 @@ sub content_menu {
 
             if ($_ =~ /((Not )?Allocated)/) {
                 print "<font color=\"$::DEL_COLOR[0]\">" if (defined $2);
-                print "<b>$1</b><br>";
+                print "<b>Status:</b> $1<br>";
                 print "</font>" if (defined $2);
             }
             elsif ($_ =~ /Group: (\d+)/) {
@@ -823,7 +821,7 @@ sub list {
     print "<center><H2>$Fs::addr_unit{$ftype}: $min - $max</H2>";
 
     my $tmp;
-    print "<font size=3>\n";
+
     if ($min - $DLS_GAP >= 0) {
         $tmp = $min - $DLS_GAP;
         print "<a href=\"$::PROGNAME?mod=$::MOD_DATA&view=$Data::LIST&"
@@ -836,7 +834,7 @@ sub list {
       . "$Args::baseargs&min=$tmp\">"
       . "<img src=\"pict/but_next.jpg\" alt=\"next\" "
       . "width=\"89\" height=20 border=\"0\"></a><br>";
-    print "</font></center>\n";
+    print "</center>\n";
 
     local *OUT;
     Exec::exec_pipe(*OUT,
@@ -857,7 +855,7 @@ sub list {
     }
     close(OUT);
 
-    print "<center><font size=3>\n";
+    print "<center>\n";
     if ($min - $DLS_GAP >= 0) {
         $tmp = $min - $DLS_GAP;
         print "<a href=\"$::PROGNAME?mod=$::MOD_DATA&view=$Data::LIST&"
@@ -870,7 +868,7 @@ sub list {
       . "$Args::baseargs&min=$tmp\">"
       . "<img src=\"pict/but_next.jpg\" alt=\"next\" "
       . "width=\"89\" height=20 border=\"0\"></a><br>";
-    print "</font></center>\n";
+    print "</center>\n";
 
     Print::print_html_footer();
     return 0;
