@@ -1,5 +1,5 @@
 #
-# $Date: 2005/04/08 19:54:05 $
+# $Date: 2005/10/13 17:02:34 $
 #
 # File name layer functions
 #
@@ -238,7 +238,7 @@ sub dir_list {
     # Field to enter a directory into:
     print "<p><form action=\"$::PROGNAME\" method=\"get\" target=\"list\">\n"
       . "<center><b>Directory Seek</b></center><br>"
-      . "<font size=2>Enter the name of a directory that you want to view<br></font>"
+      . "Enter the name of a directory that you want to view.<br>"
       . "<tt>$mnt</tt>"
       . "<input type=\"text\" name=\"dir\" size=24 maxlength=100>\n"
       . "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_FILE\">\n"
@@ -257,7 +257,7 @@ sub dir_list {
     print
       "<hr><p><form action=\"$::PROGNAME\" method=\"get\" target=\"list\">\n"
       . "<center><b>File Name Search</b></center><br>"
-      . "<font size=2>Enter a Perl regular expression for the file names you want to find<br></font>\n"
+      . "Enter a Perl regular expression for the file names you want to find.<br><br>\n"
       . "<input type=\"text\" name=\"dir\" size=24 maxlength=100>\n"
       . "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_FILE\">\n"
       . "<input type=\"hidden\" name=\"view\" value=\"$File::FILE_LIST_FILE\">\n"
@@ -1990,9 +1990,10 @@ sub content_img {
       . "&dir=$Args::enc_args{'dir'}&"
       . "cell_mode=2&recmode=$Args::enc_args{'recmode'}";
 
-    print "<tt>$fname</tt><br>\n"
+    print "<tt>$fname</tt><br><br>\n"
       . "<table><tr>\n"
-      . "<td width=200>"
+      . "<td width=250 align=\"center\">"
+      . "<b>Thumbnail:</b><br>"
       . "<img src=\"$::PROGNAME?mod=$::MOD_APPVIEW&view=$Appview::CELL_CONT${url}\" width=\"200\"></td>\n"
       . "<td valign=top>"
       . "<a href=\"$::PROGNAME?mod=$::MOD_APPVIEW&view=$Appview::CELL_CONT${url}\" "
@@ -2320,11 +2321,11 @@ sub md5list {
 # Blank Page
 sub blank {
     Print::print_html_header("");
-    print "<p><center><h3>File Browsing Mode</h3><br>\n"
-      . "In this mode, you can select a file or directory.<br>\n"
-      . "File contents will be shown in this window.<br>\n"
+    print "<br><center><h3>File Browsing Mode</h3><br>\n"
+      . "<p>In this mode, you can view file and directory contents.</p>\n"
+      . "<p>File contents will be shown in this window.<br>\n"
       . "More file details can be found using the Metadata link at the end of the list (on the right).<br>\n"
-      . "You can also sort the files using the column headers<br>\n";
+      . "You can also sort the files using the column headers</p>\n";
     Print::print_html_footer();
     return 0;
 }
