@@ -1,5 +1,5 @@
 #
-# $Date: 2005/03/06 16:51:02 $
+# $Date: 2005/10/13 17:02:34 $
 #
 # Hash database and calculation functions
 #
@@ -695,7 +695,7 @@ sub img_verify {
 
     Print::log_host_inv("$Caseman::vol2sname{$vol}: Checking image integrity");
 
-    print "<font size=3>Original MD5: <tt>$md5</tt><br>\n";
+    print "Original MD5: <tt>$md5</tt><br>\n";
 
     # We have the original value, now get the new one
     my $img = $Caseman::vol2path{$vol};
@@ -718,7 +718,7 @@ sub img_verify {
         }
         else {
             print "<font color=\"$::DEL_COLOR[0]\">Fail: Restore from backup"
-              . "</font><br>\n";
+              . "<br>\n";
 
             Print::log_host_inv(
                 "$Caseman::vol2sname{$vol}: Image integrity check FAILED");
