@@ -1,5 +1,5 @@
 #
-# $Date: 2005/02/21 03:15:53 $
+# $Date: 2005/10/13 17:02:34 $
 #
 # Metadata mode
 #
@@ -203,7 +203,7 @@ sub stats {
     }
     close(OUT);
 
-    print "<font size=3><center>\n";
+    print "<center>\n";
     print
 "<a href=\"$::PROGNAME?mod=$::MOD_META&view=$Meta::STATS&$Args::baseargs&meta=$prev\">"
       . "<img src=\"pict/but_prev.jpg\" alt=\"previous\" "
@@ -248,14 +248,14 @@ sub stats {
       . "</a></td>"
       if ($::USE_NOTES == 1);
 
-    print "</tr></table>\n</font></center>\n<font size=3>";
+    print "</tr></table>\n</center>\n";
 
     my $tmpr = $Caseman::vol2mnt{$vol};
 
     if ($ftype =~ /fat/) {
         print
 "<a href=\"$::PROGNAME?mod=$::MOD_META&view=$Meta::FFIND&$Args::baseargs&"
-          . "meta=$meta\" target=\"_blank\">Find File</a><br>";
+          . "meta=$meta\" target=\"_blank\">Search for File Name</a><br><br>";
     }
     else {
 
@@ -269,20 +269,20 @@ sub stats {
             chop;
             if (/^(\*)\s+\/*(.*)$/) {
                 Print::print_output(
-"<tt><font color=\"$::DEL_COLOR[0]\">$tmpr$2</font></tt> (deleted)<br>\n"
+"<tt><font color=\"$::DEL_COLOR[0]\">$tmpr$2</font></tt> (deleted)<br><br>\n"
                 );
             }
             elsif (/^\/(.*)$/) {
-                Print::print_output("<tt>$tmpr$1</tt><br>\n");
+                Print::print_output("<tt>$tmpr$1</tt><br><br>\n");
             }
             else {
-                Print::print_output("$_<br>\n");
+                Print::print_output("$_<br><br>\n");
             }
             $cnt++;
         }
         close(OUT);
         if ($cnt == 0) {
-            print "<br>Invalid $Fs::meta_str{$ftype} value<br>\n";
+            print "<br>Invalid $Fs::meta_str{$ftype} value<br><br>\n";
             return;
         }
     }
@@ -307,7 +307,7 @@ sub stats {
         print "<b>File Type (Recovered):</b><br>$file_type<br>\n";
     }
     else {
-        print "<b>File Type:</b><br>$file_type<br>\n";
+        print "<b>File Type:</b><br>$file_type<br><br>\n";
     }
 
     # MD5 Value
@@ -330,10 +330,10 @@ sub stats {
 
     chomp $md5out;
     if ($recmode == $File::REC_YES) {
-        print "<b>MD5 of recovered content:</b><br><tt>$md5out</tt><br>\n";
+        print "<b>MD5 of recovered content:</b><br><tt>$md5out</tt><br><br>\n";
     }
     else {
-        print "<b>MD5 of content:</b><br><tt>$md5out</tt><br>\n";
+        print "<b>MD5 of content:</b><br><tt>$md5out</tt><br><br>\n";
     }
 
     # Hash Database Lookups
@@ -395,14 +395,15 @@ sub stats {
 
     chomp $sha1out;
     if ($recmode == $File::REC_YES) {
-        print "<b>SHA-1 of recovered content:</b><br><tt>$sha1out</tt><br>\n";
+        print
+          "<b>SHA-1 of recovered content:</b><br><tt>$sha1out</tt><br><br>\n";
     }
     else {
-        print "<b>SHA-1 of content:</b><br><tt>$sha1out</tt><br>\n";
+        print "<b>SHA-1 of content:</b><br><tt>$sha1out</tt><br><br>\n";
     }
 
     # istat output
-    print "<b>Details:</b><br>\n";
+    print "<b>Details:</b><br><br>\n";
     my $mode  = 0;    # set to 1 when showing blocks
     my $force = 0;    # set to 1 if size of meta is 0
 
@@ -710,7 +711,6 @@ sub list {
 
     # Display next and previous links
     my $tmp;
-    print "<font size=3>\n";
     if ($min > $Fs::first_meta{$ftype}) {
         $tmp = $min - $ILS_GAP;
         print
@@ -723,7 +723,7 @@ sub list {
 " <a href=\"$::PROGNAME?mod=$::MOD_META&view=$Meta::LIST&$Args::baseargs&min=$tmp\">"
       . "<img src=\"pict/but_next.jpg\" alt=\"next\" "
       . "width=\"89\" height=20 border=\"0\"></a><br>";
-    print "</font></center>\n";
+    print "</center>\n";
 
     # The list
     local *OUT;
@@ -746,7 +746,7 @@ sub list {
     close(OUT);
 
     # Display next and previous links
-    print "<center><font size=3>\n";
+    print "<center>\n";
     if ($min > $Fs::first_meta{$ftype}) {
         $tmp = $min - $ILS_GAP;
         print
@@ -759,7 +759,7 @@ sub list {
 " <a href=\"$::PROGNAME?mod=$::MOD_META&view=$Meta::LIST&$Args::baseargs&min=$tmp\">"
       . "<img src=\"pict/but_next.jpg\" alt=\"next\" "
       . "width=\"89\" height=20 border=\"0\"></a><br>";
-    print "</font></center>\n";
+    print "</center>\n";
 
     Print::print_html_footer();
     return 0;
