@@ -1,5 +1,5 @@
 #
-# $Date: 2005/03/15 21:15:49 $
+# $Date: 2005/10/13 17:02:34 $
 #
 # Notes and sequencer functions
 #
@@ -886,6 +886,7 @@ sub read_seq {
       . Args::make_hidden();
 
     # Month
+    print "<table><tr><td align=\"left\">\n";
     print "<p>Date: " . "<select name=\"mon\" size=\"1\">\n";
 
     my $prev = 1;
@@ -985,20 +986,22 @@ sub read_seq {
             print "<option value=\"$sstr\">$sstr</option>\n";
         }
     }
-    print "</select>\n";
+    print "</select></td></tr>\n" . "<tr><td>&nbsp;</td></tr>\n";
 
     # Type
-    print "<br><br>Source of Event: <select name=\"src\" size=1>\n"
+    print "<tr><td align=\"left\">Event Source: <select name=\"src\" size=1>\n"
       . "<option value=\"firewall\">firewall</option>\n"
       . "<option value=\"ids\">ids</option>\n"
       . "<option value=\"isp\">isp</option>\n"
       . "<option value=\"log\">log</option>\n"
       . "<option value=\"other\" selected>other</option>\n"
       . "<option value=\"person\">person</option>\n"
-      . "</select>\n";
+      . "</select></td></tr>\n"
+      . "<tr><td>&nbsp;</td></tr>\n";
 
-    print "<p><input type=\"image\" src=\"pict/menu_b_add.jpg\" "
-      . "width=167 height=20 alt=\"Add\" border=\"0\">\n</form>\n";
+    print
+"<tr><td align=\"center\"><input type=\"image\" src=\"pict/menu_b_add.jpg\" "
+      . "width=167 height=20 alt=\"Add\" border=\"0\">\n</form></td></tr></table>\n";
 
     Print::print_html_footer();
     return 0;
