@@ -1,7 +1,7 @@
 package Print;
 
 #
-# $Date: 2005/02/21 03:15:53 $
+# $Date: 2005/10/13 17:02:34 $
 #
 # Utilities to print information
 #
@@ -49,6 +49,11 @@ sub html_encode {
 
 # remove control chars from printout
 sub print_output {
+    my $out = shift;
+    print "$out";
+# This was removed because of Unicode support
+# perhaps later some more checks can be done...
+if (0) {
     while (my $out = shift) {
         foreach $_ (split(//, $out)) {
             if (   ($_ eq "\n")
@@ -67,6 +72,7 @@ sub print_output {
         }
     }
 }
+}
 
 ############################################
 #
@@ -76,16 +82,19 @@ sub print_output {
 # This routine is used to make the minimum required header statements
 sub print_html_header_frameset {
     my $text = shift;
-    print "Content-type: text/html$::HTTP_NL$::HTTP_NL";
+    print "Content-Type: text/html; charset=utf-8$::HTTP_NL$::HTTP_NL";
 
     my $time = localtime();
 
     print <<EOF;
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <!-- Autopsy ver. $::VER Forensic Browser -->
 <!-- Page created at: $time -->
 <head>
   <title>$text</title>
+  <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
+  <link rel="stylesheet" href="/global.css">
 </head>
 
 EOF
@@ -99,7 +108,7 @@ sub print_html_footer_frameset {
 sub print_html_header {
     print_html_header_frameset(shift);
     print "<body bgcolor=\"$::BACK_COLOR\">\n\n";
-    print "<link rel=\"SHORTCUT ICON\" href=\"pict/favicon.ico\">\n";
+    print "<link rel=\"SHORTCUT ICON\" href=\"/pict/favicon.ico\">\n";
 }
 
 sub print_html_footer {
@@ -112,7 +121,7 @@ sub print_html_header_tabs {
     print_html_header_frameset(shift);
     print "<body marginheight=0 marginwidth=0 topmargin=0 "
       . "leftmargin=0 rightmargin=0 botmargin=0 bgcolor=\"$::BACK_COLOR\">\n\n";
-    print "<link rel=\"SHORTCUT ICON\" href=\"pict/favicon.ico\">\n";
+    print "<link rel=\"SHORTCUT ICON\" href=\"/pict/favicon.ico\">\n";
     $is_body = 1;
 }
 
@@ -123,17 +132,20 @@ sub print_html_footer_tabs {
 # Header for front page to warn about java script
 sub print_html_header_javascript {
     my $text = shift;
-    print "Content-type: text/html$::HTTP_NL$::HTTP_NL";
+    print "Content-Type: text/html; charset=utf-8$::HTTP_NL$::HTTP_NL";
 
     my $time = localtime();
 
     # The write line has to stay on one line
     print <<EOF;
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <!-- Autopsy ver. $::VER Forensic Browser -->
 <!-- Page created at: $time -->
 <head>
   <title>$text</title>
+  <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
+  <link rel="stylesheet" href="/global.css">
   <script language=\"JavaScript\">
   <!-- hide script from old browsers
   document.write(\'<center><font color=\"red\"><p>WARNING: Your browser currently has Java Script enabled.</font><p>You do not need Java Script to use Autopsy and it is recommended that it be turned off for security reasons.<hr></center>\');
@@ -142,7 +154,7 @@ sub print_html_header_javascript {
 </head>
 
 <body bgcolor=\"$::BACK_COLOR\">
-<link rel=\"SHORTCUT ICON\" href=\"pict/favicon.ico\">
+<link rel=\"SHORTCUT ICON\" href=\"/pict/favicon.ico\">
 
 EOF
 }
@@ -153,7 +165,7 @@ sub print_html_footer_javascript {
 
 # For raw text outputs (Pass the name of a file if it is being saved)
 sub print_text_header {
-    print "Content-type: text/plain$::HTTP_NL";
+    print "Content-Type: text/plain; charset=utf-8$::HTTP_NL";
     if (scalar @_ > 0) {
         my $fname = shift();
         print "Content-Disposition: inline; " . "filename=$fname;$::HTTP_NL";
@@ -167,7 +179,7 @@ sub print_text_footer {
 
 # For forced save outputs
 sub print_oct_header {
-    print "Content-type: application/octet-stream$::HTTP_NL";
+    print "Content-Type: application/octet-stream$::HTTP_NL";
     if (scalar @_ > 0) {
         my $fname = shift();
         print "Content-Disposition: inline; " . "filename=$fname;$::HTTP_NL";
